<?php
/* Logaholic Web Analytics software             Copyright(c) 2005-2013 Logaholic B.V.
 *                                                               All rights Reserved.
 * This code is subject to the Logaholic license. Unauthorized copying is prohibited.
 * support@logaholic.com                         http://www.logaholic.com/License.txt
*/ 
Class Subscriptions {
	var $reports = array();
	var $formArray = array();
	var $subscripts = array();
	
	function __construct(){
		$this->subscripts = $this->get_subscriptions();
	}
	
	function createReportsTable(){
		global $db;
		# Check if Reports table exists and create it if it doesn't
		$reports_table = "CREATE TABLE IF NOT EXISTS ".TBL_REPORTS." (
			`id` INT PRIMARY KEY AUTO_INCREMENT,
			`filename` VARCHAR(255) UNIQUE KEY,
			`value` LONGTEXT
			) ENGINE=MyISAM CHARSET=utf8;";
		$db->Execute($reports_table);
	}
	
	function fillReportsTable(){
		global $db, $reports;
		
		# Insert Reports into reports table
		$insert_statement = "INSERT INTO ".TBL_REPORTS." (`filename`,`value`) VALUES ";
		$first = 0;
		foreach($reports as $label => $report) {
			$report["Label"] = $label;
			$filename = $report["Filename"];
			$value = json_encode($report);
			
			if($first == 0){
				$insert_statement .="('{$filename}',". $db->quote($value) .")";
				$first = 1;
			} else {
				$insert_statement .= ",('{$filename}',". $db->quote($value) .")";
			}
		}
		$insert_statement .= " ON DUPLICATE KEY UPDATE value=VALUES(value)";
		$db->Execute($insert_statement);
	}
	
	function createSubscriptionsTable(){
		global $db;
		
		# Check if subscription table exists and create it if it doesn't
		$subscription_table = "CREATE TABLE IF NOT EXISTS ".TBL_SUBSCRIPTIONS." (
			`id` INT PRIMARY KEY AUTO_INCREMENT,
			`name` VARCHAR(255) UNIQUE KEY,
			`value` LONGTEXT
			) ENGINE=MyISAM CHARSET=utf8;";
		$db->Execute($subscription_table);
	}
	
	function createUserLogTable(){
		global $db;

		# Check if userlog table exists and create it if it doesn't
		$userlog_table = "CREATE TABLE IF NOT EXISTS ".TBL__SUBSCRIPTIONS_USERLOG." (
			`id` INT PRIMARY KEY AUTO_INCREMENT,
			`username` VARCHAR(255),
			`name` VARCHAR(255),
			`price` FLOAT(5,2),
			`timestamp` INT(11) NOT NULL default '0',
			`message` VARCHAR(255),
			KEY (`timestamp`)
			) ENGINE=MyISAM CHARSET=utf8";
		$db->Execute($userlog_table);
	}
	
	function install_subscription_system(){	
		$this->createReportsTable();
		$this->createSubscriptionsTable();
		$this->createUserLogTable();
		$this->fillReportsTable();
	}
	
	function get_reports(){
		global $db;
		@$result = $db->Execute("SELECT * FROM ".TBL_REPORTS."");
		if($result !== false) {
			while($row = $result->fetchRow()){
				$value = json_decode($row["value"],true);
				$label = $value["Label"];
				unset($value["Label"]);
				$value["ReportID"] = $row["id"];				
				$this->reports[$label] = $value;
			}
		}	
	}
	
	function get_subscriptions(){
		global $db;
		@$result = $db->Execute("SELECT * FROM ".TBL_SUBSCRIPTIONS."");
		$subs =  array();
		
		if($result !== false) {
			while($row = $result->fetchRow()){
				$value = json_decode($row["value"],true);
				$label = $row["name"];
				$value["id"] = $row["id"];
				$subs[$label] = $value;
			}
		}

		return $subs;
	}
	
	function buildFormArray(){
		global $db;
		$result = $db->Execute("SELECT * FROM ".TBL_SUBSCRIPTIONS."");		
		if($result !== false) {
			while($row = $result->fetchRow()){
				$value = json_decode($row["value"],true);
				$id = $row["id"];
				foreach($value as $k => $v){
					if($k == 'reports'){
						continue;
					}
					
					$this->formArray[$id][$k]['value'] = $v['value'];
					$this->formArray[$id][$k]['type'] = $v['type'];
					
					if($v['type'] == 'select'){
						$this->formArray[$id][$k]['options'] = $v['options'];
					}
				}
				$this->formArray[$id]["Name"]["value"] = $row["name"];
			}
		}
	}
	
	function new_subscription($posts){
		global $db;		
		foreach($posts as $label => $val){
			$label = explode("#",$label);

			if(isset($label[2])){
				$opts = explode(",",$val);
				foreach($opts as $num => $o){
					$new_values[$label[0]]['options'][$num] = $o;
				}
				$new_values[$label[0]]['type'] = $label[1];
			} else {			
				$new_values[$label[0]]['value'] = $val;
				$new_values[$label[0]]['type'] = $label[1];
			}
		}
		$name = $new_values["Name"]['value'];
		
		$value = json_encode($new_values);
		
		$db->Execute("INSERT IGNORE INTO ".TBL_SUBSCRIPTIONS." (`name`,`value`) VALUES (".$db->quote($name).",".$db->quote($value).")");
	}
	
	function edit_reports($subscrId, $reports){
		global $db;
		
		$result = $db->Execute("SELECT * FROM ".TBL_SUBSCRIPTIONS." WHERE id={$subscrId}");
		$subscription = $result->fetchRow();
		$value = json_decode($subscription['value'],true);
		
		# Check if there are reports stored for this subscription. If so add them if not set them.
		$value['reports'] = $reports;
		
		$value = json_encode($value);
		$db->Execute("UPDATE ".TBL_SUBSCRIPTIONS." SET value=".$db->quote($value)." WHERE id={$subscrId}");
	}
	
	function edit_subscription($posts){
		global $db;	
		$subscrId = $posts["id#hidden"];
		$result = $db->Execute("SELECT * FROM ".TBL_SUBSCRIPTIONS." WHERE id={$subscrId}");
		$subscription = $result->fetchRow();
		$value = json_decode($subscription['value'],true);
		if(isset($value['reports'])){
			$new_values['reports'] = $value['reports'];
		}
		foreach($posts as $label => $val){
			$label = explode("#",$label);
			
			if(isset($label[2])){
				$opts = explode(",",$val);
				foreach($opts as $num => $o){
					$new_values[$label[0]]['options'][$num] = $o;
				}
				$new_values[$label[0]]['type'] = $label[1];
			} else {			
				$new_values[$label[0]]['value'] = $val;
				$new_values[$label[0]]['type'] = $label[1];
			}
		}
		$name = $new_values["Name"]['value'];
		$value = json_encode($new_values);
		$db->Execute("UPDATE ".TBL_SUBSCRIPTIONS." SET value=".$db->quote($value).", name=".$db->quote($name)." WHERE id={$subscrId}");
	}
	
	function delete_subscription($id,$setto){
		global $db;
		if($setto == 0){
			$db->Execute("UPDATE ".TBL_USERS." SET subscriptionid = null WHERE subscriptionid= {$id}");
		} else {
			$db->Execute("UPDATE ".TBL_USERS." SET subscriptionid = {$setto} WHERE subscriptionid= {$id}");
		}
		$db->Execute("DELETE FROM ".TBL_SUBSCRIPTIONS." WHERE id = {$id}");
	}
	
	function ui_report_list(){
		$this->get_reports();
		foreach($this->reports as $l => $r){
			if(defined($l)){
				echo "<li class='' rel='{$r["ReportID"]}' src='{$r["Filename"]}'><span class='reportname'>". constant($l) ."</span></li>";
			}
		}
	}	
	
	
	function ui_delete_form(){
		echo "Your are about to delete a subscription <b class='subscription_tag'>(#SUBSCRIPTION#)</b>:<br/>";
		
		echo "What do you want to do with the users that are using this subscription?</br><br/>";
		echo "By just removing the subscription the users will be able to see all the reports.<br/>";
		echo "<br/><form method='POST' action='subscriptions.php'><select name='deletesub'><option value='0'>Remove the subscription*</option>";
		foreach($this->subscripts as $name => $values){
			echo "<option class='remove-{$name}' value='{$values["id"]}'>Set user subscriptions to: {$name}</option>";
		}
		echo "</select><br/>";
		echo "<input type='hidden' value='' id='subtodelete' name='subtodelete' />";
		echo "<div style='float:left; margin-top:30px; width:100%'>";
		echo "<div><input class='button_wrapper delete-button' type='submit' value='"._DELETE."'/></div>";
		echo "<div class='button_wrapper cancel-reset' style='float:left;'><a class='close-popup' href='#'>"._CANCEL."</a></div>";
		echo "</div></form>";
	}
	
	function ui_edit_form(){
		global $form;
		$this->buildFormArray();
		foreach($this->formArray as $id => $data){
			
			$data["subedit"]["value"] = "Save Changes";
			$data["subedit"]["type"] = "submit";
			$data["id"]["value"] = $id;
			$data["id"]["type"] = "hidden";
			
			$form->CreateForm($data,"edit-sub-$id custom-form");
		}
	}
	
	function ui_subscription_list(){

		foreach($this->subscripts as $name => $values){
			echo "<li><div class='subscriptionname selected' name='{$name}' rel='{$values["id"]}'><span class='name'>{$name}</span>";
			echo "<a class='delete-subscription' title='Delete this subscription' name='{$name}' rel='{$values["id"]}'></a>";
			echo "<a class='edit-subscription' title='Edit this subscription' name='".$name."' rel='".$values["id"]."' price='".@$values["Price"]['value']."'></a>";
			echo "<a class='copy-subscription' title='Copy this subscription' name='{$name}'></a>";
			echo "</div><ul class='subscriptioncontent'>";
			if(!empty($values["reports"])){
				$this->get_reports();
				foreach($this->reports as $l => $r){
					if(in_array($r["ReportID"],$values["reports"])){
						echo "<li class='' rel='{$r["ReportID"]}' src='{$r["Filename"]}'><span class='reportname'>". constant($l) ."</span></li>";
					}	
				}	
			}
			echo "</ul>
			</li>";
		}
	}
	
	function new_subscription_form(){
		global $form;
		
		$this->buildFormArray();

		if(empty($this->formArray[0])){
			$this->formArray[0] = array(
				"id" => array("value" => 0,"type" => "hidden")
				,"Name" => array("value" => "","type" => "input")
				,"Display_Price" => array("value" => "","type" => "input")
				,"Price" => array("value" => "","type" => "input")
				,"KPI Limit" => array("value" => "","type" => "input")
				,"PDF" => array("value" => "","type" => "select", "options" => array("Enabled","Disabled"))
				,"Dashboards" => array("value" => "","type" => "select", "options" => array("Enabled","Disabled"))
				,"Update" => array("value" => "","type" => "select", "options" => array("Enabled","Disabled"))
			);
		}
		
		$num = 0;
		$getfromsub = 0;
		foreach($this->formArray as $subscrip => $vals){			
			if(count($vals) > $num) {
				$num = count($vals);
				$getfromsub = (int)$subscrip;
			}
			
		}
		$data = array();
		if (isset($this->formArray[$getfromsub])) {
			foreach($this->formArray[$getfromsub] as $k => $v){
				$data[$k]['value'] = '';
				if(isset($v['type'])){
					$data[$k]['type'] = $v['type'];
				}else{
					$data[$k]['type'] = '';
				}
				if(isset($v['options'])){
					$data[$k]['options'] = $v['options'];
				}
			}
		}

		$data["subsave"]["value"] = "Add New Subscription";
		$data["subsave"]["type"] = "submit";

		$form->CreateForm($data,"new-sub-form custom-form");
	}
	
	function getSubscription($name) {
		global $db;
		$result = $db->Execute("SELECT * FROM ".TBL_SUBSCRIPTIONS." where name = ".$db->Quote($name)."");
		if($result !== false) {
			$row = $result->fetchRow();
			return $row;			
		}
	}
	
	
	function copySubscription($source,$target) {
		global $db;
		$data = $this->getSubscription($source);
		$value = $data['value'];
		$db->Execute("INSERT IGNORE INTO ".TBL_SUBSCRIPTIONS." (`name`,`value`) VALUES (".$db->quote($target).",".$db->quote($value).")");
		
	}
	
	
}
?>