<?php
/* Logaholic Web Analytics software             Copyright(c) 2005-2013 Logaholic B.V.
 *                                                               All rights Reserved.
 * This code is subject to the Logaholic license. Unauthorized copying is prohibited.
 * support@logaholic.com                         http://www.logaholic.com/License.txt
*/ 
/**
* @desc This report displays the error report
*/

$reports["_BOUNCE_RATE"] = Array(
	"ClassName" => "BounceRate", 
	"Category" => "_POPULAR_CONTENT", 
	"icon" => "images/icons/32x32/bouncerate.png",
	"Options" => "daterangeField,profileselector,displaymode",
	"Filename" => "bounce_rate",
	"Distribution" => "Standard",
	"Order" => 11,
	"ReportVersion" => 1.0,
	"MinimumVersion" => 3.1,
	"EmailAlerts" => true,
	"Update" => false
);

class BounceRate extends Report {
	
	function Settings() {
		$this->DefaultDisplay = "table";
		$this->DisplayModes = "table,pie,linechart";
		$this->columnDefinitions[] = array( "Label" => _DESCRIPTION);
		$this->columnDefinitions[] = array( "Label" => _VALUE,"dataType" => "String");
		
		
		$this->help = _BOUNCE_RATE_DESC;
		$this->dataCollectType = "days";
		$this->displayTotalRow = false;
		$this->sparktype = 'pie';
		if (!empty($this->page)) {
			$this->addlabel = $this->page;
			$this->fileNameExpension = ".".urlencode($this->page);
		}
	}
	
	function GetDataFromDb() {
		global $db, $reports;
		$data=array();
		
		if (empty($this->page)) {
			$this->displaymode = 'table';
			
			# first get total number of visitors to page
			$vpd = new $reports["_VISITORS_PER_DAY"]["ClassName"]();
			$vpd->from = $this->from;
			$vpd->to = $this->to;
			$total_visitors = $vpd->GetReportData();			

			# Get the bounce visitors 
			$query ="SELECT count(visitorid) from (SELECT visitorid, count(*) as hits from {$this->profile->tablename} WHERE timestamp >=". $db->Quote($this->from) ." and timestamp <=". $db->Quote($this->to) ." GROUP BY visitorid ORDER by NULL) as ht where hits=1";
			$result = $db->Execute($query); 
			$i = 0;
			while($bounce_visitors = $result->FetchRow()){
				$data[$i][0] = $this->to;
				$data[$i][1] = @($total_visitors[$i][1] == 0) ? 0.00 : ($bounce_visitors[0] / $total_visitors[$i][1]) * 100;
				$data[$i][2] = $bounce_visitors[0];
				$i ++;
			}		
			return $data;
		}
		
		$pageid = getID($this->page,'urls');
		if (empty($pageid)) {
			return $data;
		}
		
		# clean up temp table
		$db->Execute("drop temporary table if exists goodtimes"); 
		
		# get the visitorid and timestamp of the request we're interested in 
		$db->Execute("CREATE TEMPORARY TABLE goodtimes select visitorid,timestamp from {$this->profile->tablename} where url=".$pageid." and timestamp >=". $db->Quote($this->from) ." and timestamp <=". $db->Quote($this->to));
		
		# first get total number of visitors to page
		$query = "select count(distinct visitorid) from goodtimes";
		$result = $db->Execute($query); 
		$total_visits = $result->FetchRow();
		$total_visits = $total_visits[0];    
		if ($total_visits < 1) {
			return $data;
		}
		
		# count how many visitors have hits beyond the timestamp we just found
		$query = "select count(distinct a.visitorid) from {$this->profile->tablename} as a, goodtimes as b where b.visitorid=a.visitorid and a.timestamp > b.timestamp and a.timestamp <= ". $db->Quote($this->to);
		$result = $db->Execute($query); 
		$stay_visits = $result->FetchRow();
		$stay_visits = $stay_visits[0];
		
		$bounce_visits = $total_visits - $stay_visits;
		$bounce_rate = $bounce_visits / $total_visits * 100;
		
		$data=array();
		
		// if ($this->displaymode == 'pie') {
			
			$data[0][0] = "Visitors that stayed";
			$data[0][1] = $stay_visits;
			
			// $data[1][0] = "Visitors left (Bounce Rate)";
			$data[1][0] = "Visitors left";
			$data[1][1] = $bounce_visits;
		// } else {
			$data[2][0] = "Total Visitors";
			$data[2][1] = $total_visits;
			
			$data[3][0] = "Bounce rate";
			$data[3][1] = number_format($bounce_rate,0);
		// }
		
		# clean up temp table
		$db->Execute("drop temporary table goodtimes"); 
		
		return $data;      
	}
	
	function GetReportData() {
		global $db, $get_constant;
		
		$data = parent::GetReportData();
		$dat = array();
		
		$range = $this->to - $this->from;
		$days = round($range / 86400);
		if($days <= 0){ $days = 1; }
		
		if(empty($this->page)){
			$i = 0;
			$total = 0;
			
			
			if ($this->displaymode == 'pie') {			
				$bounce = number_format(($total / $days),2);
				
				
				$dat[0][0] = _VISITORS_STAYED;
				$dat[0][1] = 100 - $bounce;
				
				$dat[1][0] = _VISITORS_LEFT . " (". _BOUNCE_RATE .")";
				$dat[1][1] = $bounce;
			} else {
				foreach($data as $br){
					if(is_numeric($br[0])){
						$dat[$i][0] = date(implode($this->profile->dateFormat),$br[0]);	
					} else {
						$dat[$i][0] = $br[0];
					}

					if ($this->displaymode == 'table') {	
						$dat[$i][1] = number_format($br[1],2). "%";	
					} else {
						$dat[$i][1] = number_format($br[1],2);
					}


					$total = $total + $br[1];
					$i ++;
				}
			}
				
			return $dat;
		}
		
		
		# WARNING the keys in the data array are shafted because they are sorted on value key : 0 = Bounce rate, 1 = Total Visitors etc alphabetic...
		if ($this->displaymode == 'pie') {			
			$dat[0][0] = _VISITORS_STAYED;
			$dat[0][1] = number_format(($data[3][1] / $days),2);
			
			$dat[1][0] = _VISITORS_LEFT . " (". _BOUNCE_RATE .")";
			$dat[1][1] = number_format(($data[2][1] / $days),2);
		} else {
			
			$dat[0][0] = _VISITORS_STAYED;
			$dat[0][1] = number_format(($data[3][1] / $days),2);
			
			$dat[1][0] = _VISITORS_LEFT;
			$dat[1][1] = number_format(($data[2][1] / $days),2);
			
			$dat[2][0] = _TOTAL;
			$dat[2][1] = number_format(($data[1][1] / $days),2);
			
			$dat[3][0] = _BOUNCE_RATE;
			$dat[3][1] = number_format(($data[0][1] / $days),2);
			
			
		}
		return $dat;
	}
	
	function DisplayCustomForm() {
		global $ourpath;
		echo "<div>";
		echo "<label for='page'>"._PAGE.":</label>";
		echo "<input class='report_option_field' type='text' name='page' id='page' value='".@$this->page."' onkeyup=\"popupActionMenu(event, this.value+'@'+this.id+'@'+'page', 'forminput');\" onclick=\"popupActionMenu(event, this.value+'@'+this.id+'@'+'page', 'forminput');\">";
		echo "</div>";
	}
	
	function DisplaySparkline() {
		$this->displaymode = 'pie';
		$data = $this->GetReportData();
		$postfix = $data[1][1] / ( $data[1][1]+ $data[0][1]) * 100;
		$postfix = number_format($postfix,0)."%";
        $this->Sparkline($data,$this->sparktype,_BOUNCE_RATE,$postfix);
    }
	
	function UpdateStats(){
		return false;
	}
}
?>
