<?php
/* Logaholic Web Analytics software             Copyright(c) 2005-2013 Logaholic B.V.
 *                                                               All rights Reserved.
 * This code is subject to the Logaholic license. Unauthorized copying is prohibited.
 * support@logaholic.com                         http://www.logaholic.com/License.txt
*/ 
/**
* @desc This report lets you make split test of your pages and gives you an overview of wich one works the best.
*/

$reports["_TRAFFIC_OVERVIEW"] = Array(
	"ClassName" => "TrafficOverview", 
	"Category" => "_TRAFFIC",
	"icon" => "images/icons/32x32/traffic_breakdown.png",
	"Options" => "daterangeField,profileselector",
	"Filename" => "traffic_overview",
	"Distribution" => "Standard",
	"Order" => 1,
	"ReportVersion" => 1.0,
	"MinimumVersion" => 3.0,
	"EmailAlerts" => true,
	"DeleteOutdatedFiles" => false,
	"Update" => false
);

class TrafficOverview extends Report {
	function Settings() {
		?><style type="text/css">
		
		</style><?php		
	}
	
	function GetErrorData(){
		$r = new ErrorReport();
		$r->dataCollectType = "days";
		$r->createDataFiles($this->from,$this->to);	
		$error_data = $r->getTrendDataFromFiles($r->DataFiles($r->from,$r->to));

		$data = array();
		$total = 0;
		$i = 0;

		foreach($error_data as $k => $entry){
			$timestamp = mktime(0,0,0,substr($k,4,-2),substr($k,6,7),substr($k,0,4));
			$date = LogaDate($this->profile->dateFormat,$timestamp);

			# prefill
			if(empty($data[$i])){
				$data[$i][0] = $date;
				$data[$i][1] = 0;
			}

			foreach ($entry as $d) {
				$data[$i][1] = $data[$i][1] + $d[1]; 
				$total += $d[1]; 
			}


			$i ++;
		}

		return array(
			"data" => $data
			,"value" => $total
		);
	}

	function GetPercentageData($label,$k,$v){
		global $reports;

		$r = new $reports[$label]["ClassName"]();
		$report_data = $r->GetReportData();
		
		$data = array();
		$total = 0;
		$avg = 0;
		$i = 0;

		foreach($report_data as $day => $vals){
			$perc = (int)substr($vals[$v],0, -1);
			$data[] = array(LogaDate($this->profile->dateFormat,$vals[$k], "STRING") , $perc );			
			$total += $perc;
			$i ++;
		}

		if($i == 0){
			$avg = 0;
		} else {
			$avg = number_format(($total / $i),2) . "%";
		}

		return array(
			"data" => $data
			,"value" => $avg
		);
	}

	function GetConversionData(){
		$r = new OverallPerformance();
		$r->dataCollectType = "days";
		$r->createDataFiles($r->from,$r->to);
		$performance_data = $r->getTrendDataFromFiles($r->DataFiles($r->from,$r->to));

		$data = array();
		$total = 0;
		$avg = 0;
		$i = 0;

		foreach($performance_data as $k => $entry){
			$timestamp = mktime(0,0,0,substr($k,4,-2),substr($k,6,7),substr($k,0,4));
			$date = LogaDate($this->profile->dateFormat,$timestamp);

			# prefill
			if(empty($data[$i])){
				$data[$i][0] = $date;
				$data[$i][1] = 0;
			}

			$ii = 0;

			foreach ($entry as $d) {
				$data[$i][1] = $data[$i][1] + $d[3]; 
				$ii ++;
			}

			$data[$i][1] = number_format( ($data[$i][1] / $ii) ,2);
			$total += $data[$i][1];

			$i ++;
		}

		# if there is no data set to zero
		if($i == 0){
			$avg = 0;
		} else {
			$avg = $total / $i;
		}
		$perc = number_format( $avg ,2) . "%";

		return array(
			"data" => $data
			,"value" => $perc
		);
	}
	
	function DisplayReport(){
		$this->ReportHeader();

		$vpd = new VisitorsPerDay();
		$vpd_data = $vpd->GetReportData();

		# Prepare the visits Data Set
		$visits_data = array();		
		$total_visits = 0;

		$pageviews_data = array();
		$total_pageviews = 0;

		$pagespervisit_data = array();
		$total_pagespervisit = 0;

		$data = array();
		$trend_data = array();
		$trend_slope = 0;

		$i = 0;
		foreach($vpd_data as $day => $vals){
			# Date
			$date = LogaDate($this->profile->dateFormat,$vals[0], "STRING");
			
			# Visits Data set
			$visits = $vals[4];
			$visits_data[] = array($date , $visits );
			$total_visits += $visits;

			# Pageviews Data set
			$pageviews = $vals[2];
			$pageviews_data[] = array($date , $pageviews );
			$total_pageviews += $pageviews;

			# Pages per visit
			$pagespervisit = number_format($vals[3],2);
			$pagespervisit_data[] = array($date , $pagespervisit );
			$total_pagespervisit += $pagespervisit;

			$i ++;

			# Trend Data
			$data[$i] = $visits;
		}

		if($i == 0){
			$avg_ppv = 0;
		} else {
			$avg_ppv = number_format( ($total_pagespervisit / $i) ,2 );
		}

		# Caculate the slope of the trend and get the average visits count to start the trend with
		$trend_slope = round( $this->CalcTrendData($data) );
		if($i == 0){
			$start_trend = 0;
		} else {
			$start_trend = round( ($total_visits / $i) );
		}
		
		for($i = 0; $i < count($data); $i++){
			# Use the visits array to collect the date
			$t = number_format($start_trend) + ( $i * $trend_slope );
			$trend_data[] = array( $visits_data[$i][0] , $t );
		}		

		# TopCountriesCities
		$worldmap = new TopCountriesCities();
		$worldmapdata = $worldmap->GetReportData();

		# BrowserBreakdown
		$browserbreak = new BrowserBreakdown();
		$browserbreak->displayHeader = false;
		$browserbreak->hidelegenda = true;
		$browserbreakdata = $browserbreak->GetReportData();
		$browserbreakdata = $browserbreak->ConvertData($browserbreakdata);

		# New VS Returning
		$newvsreturning = $this->GetPercentageData("_NEW_VS_RETURNING",0,1);
		
		$bouncerate = $this->GetPercentageData("_BOUNCE_RATE",0,1);
		
		$errors = $this->GetErrorData();

		$conversion = $this->GetConversionData();

		# Get 60 Days range
		$from = $vpd->from;
		$to = $vpd->to;
		$dif = $to - $from;

		if( ($dif / 86400) < 60){
			$vpd->from = mktime(0,0,0,date("m",$vpd->to),date("d",$vpd->to) - 60,date("Y",$vpd->to));
		}
		$bigrange_data = $vpd->GetReportData();

		$json_data = array();
		foreach($bigrange_data as $data){
			$json_data[] = array( (strtotime($data[0]) * 1000) ,  (int)$data[4] );
		}
		?>
		<div class="trafficoverview-wrapper">
			
			<div class="trafficoverview-top">
				<div class="quarter-block">
					<div style="float:left; height:70%; width: 100%;">
						<?php $this->MiniChart($visits_data, _TOTAL_VISITS, number_format($total_visits)); ?>
					</div>
					<div style="float:left; height:30%; width: 100%;">
						<?php
						if($trend_slope >= 0){ $color = "#339933"; } else { $color = "#FF0000";  }
						$this->MiniChart($trend_data, _VISITS_TRENDS, $trend_slope, $color); 
						?>						
					</div>
				</div>
				<div class="half-block">
					<?php $worldmap->WorldMap($worldmapdata,200,"#FFFFFF"); ?>
				</div>
				<div class="quarter-block">
					<div style="float:right; height:70%; width: 100%;">				
						<?php $this->MiniChart($pageviews_data, _TOTAL_PAGEVIEWS, number_format($total_pageviews),"#000000", 'right'); ?>								
					</div>
					<div style="float:right; height:30%; width: 100%;">	
						<?php $this->MiniChart($pagespervisit_data, _PAGES_PER_USER, $avg_ppv,"#000000", 'right'); ?>							
					</div>
				</div>
			</div>

			<div class="trafficoverview-center">
				<?php
				$d3graph_class = "D3" . md5(time());
				echo "<div><svg style='height:100%;' class='$d3graph_class d3graph'></svg></div>";
				?>				
			</div>

			<div class="trafficoverview-bottom">
				<div class="quarter-block">
					<div style="float:left; height:50%; width: 100%;">
						<?php $this->MiniChart($newvsreturning["data"], _NEW_VS_RETURNING, $newvsreturning["value"]); ?>
					</div>
					<div style="float:left; height:50%; width: 100%;">
						<?php $this->MiniChart($bouncerate["data"], _BOUNCE_RATE, $bouncerate["value"]); ?>
					</div>
				</div>
				<div class="half-block">
					<?php $browserbreak->CreateDonut($browserbreakdata); ?>
					
				</div>
				<div class="quarter-block">
					<div style="float:right; height:50%; width: 100%;">				
						<?php $this->MiniChart($errors["data"], _SITE_ERRORS, number_format($errors["value"]) ,"#000000", 'right'); ?>									
					</div> 
					<div style="float:right; height:50%; width: 100%;">											
						<?php $this->MiniChart($conversion["data"], _CONVERSION_RATE, $conversion["value"],"#000000", 'right'); ?>							
					</div>
				</div>
			</div>

		</div>
		<script type="text/javascript">
		var data_set = [
		  {
		    "key" : "<?php echo _VISITS_PER_DAY; ?>" ,
		    "values" : <?php echo json_encode($json_data); ?>
		  }
		];

		var colors = d3.scale.category20();
		keyColor = function(d, i) {return colors(d.key)};

		var chart;
		nv.addGraph(function() {
		  chart = nv.models.stackedAreaChart()
		  			.margin({right: 50})
	    			.showControls(false)
	    			// .showLegend(false)
	                .useInteractiveGuideline(true)
	                .x(function(d) { return d[0] })
	                .y(function(d) { return d[1] })
	                .color(keyColor);

		  chart.xAxis
		      .tickFormat(function(d) { return d3.time.format('%x')(new Date(d)) });

		  chart.yAxis
		      .tickFormat(d3.format('2f'));


		  d3.select('.<?php echo $d3graph_class; ?>')
		    .datum(data_set)
		    // .transition().duration(1000)
		    .call(chart)

		  nv.utils.windowResize(chart.update);
		  return chart;
		});
		</script>
		<?php
	}

	function CalcTrendData($data){
		$a = 0;
		$c = 0;
		
		$bx = 0;
		$by = 0;
		
		foreach($data as $k => $v){
			$a = $a + ($k * $v);
			$bx += $k;
			$by += $v;

			$c = $c + pow($k,2);
		}
		

		$a = $a * count($data);
		$c = $c * count($data);
		$b = $bx * $by;
		$d = pow($bx,2);
		
		if( ($c - $d) <= 0 ){
			$result = 0;
		} else {
			$result = ($a - $b) / ($c - $d);
		}

		return $result;
	}

	function MiniChart($data, $label = "", $value = "" , $value_color = "#000000" , $align = "left"){
		$id = "MC" . md5($label.time());

		$t = $this->ConvertToSparklineData($data);

		echo "<div class='minichart' style='float:{$align};'>";
			echo "<div class='header'>$label</div>";
			echo "<div class='value' style='color:{$value_color};'>$value</div>";

			echo "<div class='sparkchart spark-{$id}'>"; 
				?><script type='text/javascript'>
				$('.spark-<?php echo $id; ?>').sparkline( [ <?php echo $t["values"]; ?> ] , { 
					type: 'line'
					,tooltipFormat: '<span style="color: {{color}}">&#9679;</span> {{offset:names}}  ({{y}})'
					,tooltipValueLookups: { names: { <?php echo $t["names"]; ?> } }							
				});				
				</script><?php
			echo "</div>";
		echo "</div>";
	}

	function UpdateStats(){
		return false;
	}
}